@@ -37,8 +37,6 @@ class TestModelLine(TestCase):
 
         model = line[0]
 
-        shutil.rmtree('./line')  # Cleanup
-
         self.assertEqual(len(line), 1)
         self.assertTrue(model.model == "b'model'")
 
@@ -49,8 +47,6 @@ class TestModelLine(TestCase):
 
         line.save(m)
 
-        shutil.rmtree('./line_meta')  # Cleanup
-
         meta = line.get_meta()
         self.assertEqual(meta[0]['model_cls'], repr(DummyModel))
         self.assertEqual(meta[0]['len'], 1)
